pub struct Position {
pub start: u32,
pub end: u32,
}Expand description
A position or span of text in the source code.
Fields
start: u32The starting index of the position, byte-wise. This is inclusive.
end: u32The ending index of the position, byte-wise. This is exclusive.
Implementations
Sourceimpl Position
impl Position
Sourcepub fn new(start: usize, end: usize) -> Self
pub fn new(start: usize, end: usize) -> Self
Creates a new position from a start and end index.
Sourcepub fn starting_char(&self) -> usize
pub fn starting_char(&self) -> usize
Returns the starting index of the position.
Sourcepub fn ending_char(&self) -> usize
pub fn ending_char(&self) -> usize
Returns the ending index of the position. Note that this is exclusive, so
self.end - 1 is the last index of the position.