Position

Struct Position 

pub struct Position {
    pub start: u32,
    pub end: u32,
}
A position or span of text in the source code.

Fields

start: u32

The starting index of the position, byte-wise. This is inclusive.

end: u32

The ending index of the position, byte-wise. This is exclusive.

Implementations

Source

impl Position

pub fn new(start: usize, end: usize) -> Self

Creates a new position from a start and end index.

pub fn starting_char(&self) -> usize

Returns the starting index of the position.

pub fn ending_char(&self) -> usize

Returns the ending index of the position. Note that this is exclusive, so self.end - 1 is the last index of the position.

pub fn join(&self, other: &Self) -> Self

Joins two positions together.

pub fn len(&self) -> usize

Returns the length of the position.

pub fn is_empty(&self) -> bool

Returns whether or not the position is empty (i.e., the start and end are the same). This means that the position is an EOF.